@@ -1,5 +1,5 @@
 /* kwset.c - search for any of a set of keywords.
-   Copyright (C) 1989, 1998, 2000, 2005, 2007, 2009-2010 Free Software
+   Copyright (C) 1989, 1998, 2000, 2005, 2007, 2009-2012 Free Software
    Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
    The author may be reached (Email) at the address mike@ai.mit.edu,
    or (US mail) as Mike Haertel c/o Free Software Foundation. */
 
-/* The algorithm implemented by these routines bears a startling resemblence
+/* The algorithm implemented by these routines bears a startling resemblance
    to one discovered by Beate Commentz-Walter, although it is not identical.
    See "A String Matching Algorithm Fast on the Average," Technical Report,
    IBM-Germany, Scientific Center Heidelberg, Tiergartenstrasse 15, D-6900
@@ -40,7 +40,7 @@
 #ifdef GREP
 # include "xalloc.h"
 # undef malloc
-# define malloc(s) xmalloc(s)
+# define malloc xmalloc
 #endif
 
 #define NCHAR (UCHAR_MAX + 1)
@@ -62,21 +62,21 @@ struct tree
 /* Node of a trie representing a set of reversed keywords. */
 struct trie
 {
-  unsigned int accepting;	/* Word index of accepted word, or zero. */
+  size_t accepting;		/* Word index of accepted word, or zero. */
   struct tree *links;		/* Tree of edges leaving this node. */
   struct trie *parent;		/* Parent of this node. */
   struct trie *next;		/* List of all trie nodes in level order. */
   struct trie *fail;		/* Aho-Corasick failure function. */
   int depth;			/* Depth of this node from the root. */
   int shift;			/* Shift function for search failures. */
-  int maxshift;			/* Max shift of self and descendents. */
+  int maxshift;			/* Max shift of self and descendants. */
 };
 
 /* Structure returned opaquely to the caller, containing everything. */
 struct kwset
 {
   struct obstack obstack;	/* Obstack for node allocation. */
-  int words;			/* Number of words in the trie. */
+  ptrdiff_t words;		/* Number of words in the trie. */
   struct trie *trie;		/* The trie itself. */
   int mind;			/* Minimum depth of an accepting node. */
   int maxd;			/* Maximum depth of any node. */
@@ -151,122 +151,122 @@ kwsincr (kwset_t kws, char const *text, size_t len)
       label = kwset->trans ? kwset->trans[U(*--text)] : *--text;
 
       /* Descend the tree of outgoing links for this trie node,
-	 looking for the current character and keeping track
-	 of the path followed. */
+         looking for the current character and keeping track
+         of the path followed. */
       link = trie->links;
       links[0] = (struct tree *) &trie->links;
       dirs[0] = L;
       depth = 1;
 
       while (link && label != link->label)
-	{
-	  links[depth] = link;
-	  if (label < link->label)
-	    dirs[depth++] = L, link = link->llink;
-	  else
-	    dirs[depth++] = R, link = link->rlink;
-	}
+        {
+          links[depth] = link;
+          if (label < link->label)
+            dirs[depth++] = L, link = link->llink;
+          else
+            dirs[depth++] = R, link = link->rlink;
+        }
 
       /* The current character doesn't have an outgoing link at
-	 this trie node, so build a new trie node and install
-	 a link in the current trie node's tree. */
+         this trie node, so build a new trie node and install
+         a link in the current trie node's tree. */
       if (!link)
-	{
-	  link = (struct tree *) obstack_alloc(&kwset->obstack,
-					       sizeof (struct tree));
-	  if (!link)
-	    return _("memory exhausted");
-	  link->llink = NULL;
-	  link->rlink = NULL;
-	  link->trie = (struct trie *) obstack_alloc(&kwset->obstack,
-						     sizeof (struct trie));
-	  if (!link->trie)
-	    {
-	      obstack_free(&kwset->obstack, link);
-	      return _("memory exhausted");
-	    }
-	  link->trie->accepting = 0;
-	  link->trie->links = NULL;
-	  link->trie->parent = trie;
-	  link->trie->next = NULL;
-	  link->trie->fail = NULL;
-	  link->trie->depth = trie->depth + 1;
-	  link->trie->shift = 0;
-	  link->label = label;
-	  link->balance = 0;
+        {
+          link = (struct tree *) obstack_alloc(&kwset->obstack,
+                                               sizeof (struct tree));
+          if (!link)
+            return _("memory exhausted");
+          link->llink = NULL;
+          link->rlink = NULL;
+          link->trie = (struct trie *) obstack_alloc(&kwset->obstack,
+                                                     sizeof (struct trie));
+          if (!link->trie)
+            {
+              obstack_free(&kwset->obstack, link);
+              return _("memory exhausted");
+            }
+          link->trie->accepting = 0;
+          link->trie->links = NULL;
+          link->trie->parent = trie;
+          link->trie->next = NULL;
+          link->trie->fail = NULL;
+          link->trie->depth = trie->depth + 1;
+          link->trie->shift = 0;
+          link->label = label;
+          link->balance = 0;
 
-	  /* Install the new tree node in its parent. */
-	  if (dirs[--depth] == L)
-	    links[depth]->llink = link;
-	  else
-	    links[depth]->rlink = link;
+          /* Install the new tree node in its parent. */
+          if (dirs[--depth] == L)
+            links[depth]->llink = link;
+          else
+            links[depth]->rlink = link;
 
-	  /* Back up the tree fixing the balance flags. */
-	  while (depth && !links[depth]->balance)
-	    {
-	      if (dirs[depth] == L)
-		--links[depth]->balance;
-	      else
-		++links[depth]->balance;
-	      --depth;
-	    }
+          /* Back up the tree fixing the balance flags. */
+          while (depth && !links[depth]->balance)
+            {
+              if (dirs[depth] == L)
+                --links[depth]->balance;
+              else
+                ++links[depth]->balance;
+              --depth;
+            }
 
-	  /* Rebalance the tree by pointer rotations if necessary. */
-	  if (depth && ((dirs[depth] == L && --links[depth]->balance)
-			|| (dirs[depth] == R && ++links[depth]->balance)))
-	    {
-	      switch (links[depth]->balance)
-		{
-		case (char) -2:
-		  switch (dirs[depth + 1])
-		    {
-		    case L:
-		      r = links[depth], t = r->llink, rl = t->rlink;
-		      t->rlink = r, r->llink = rl;
-		      t->balance = r->balance = 0;
-		      break;
-		    case R:
-		      r = links[depth], l = r->llink, t = l->rlink;
-		      rl = t->rlink, lr = t->llink;
-		      t->llink = l, l->rlink = lr, t->rlink = r, r->llink = rl;
-		      l->balance = t->balance != 1 ? 0 : -1;
-		      r->balance = t->balance != (char) -1 ? 0 : 1;
-		      t->balance = 0;
-		      break;
-		    default:
-		      abort ();
-		    }
-		  break;
-		case 2:
-		  switch (dirs[depth + 1])
-		    {
-		    case R:
-		      l = links[depth], t = l->rlink, lr = t->llink;
-		      t->llink = l, l->rlink = lr;
-		      t->balance = l->balance = 0;
-		      break;
-		    case L:
-		      l = links[depth], r = l->rlink, t = r->llink;
-		      lr = t->llink, rl = t->rlink;
-		      t->llink = l, l->rlink = lr, t->rlink = r, r->llink = rl;
-		      l->balance = t->balance != 1 ? 0 : -1;
-		      r->balance = t->balance != (char) -1 ? 0 : 1;
-		      t->balance = 0;
-		      break;
-		    default:
-		      abort ();
-		    }
-		  break;
-		default:
-		  abort ();
-		}
+          /* Rebalance the tree by pointer rotations if necessary. */
+          if (depth && ((dirs[depth] == L && --links[depth]->balance)
+                        || (dirs[depth] == R && ++links[depth]->balance)))
+            {
+              switch (links[depth]->balance)
+                {
+                case (char) -2:
+                  switch (dirs[depth + 1])
+                    {
+                    case L:
+                      r = links[depth], t = r->llink, rl = t->rlink;
+                      t->rlink = r, r->llink = rl;
+                      t->balance = r->balance = 0;
+                      break;
+                    case R:
+                      r = links[depth], l = r->llink, t = l->rlink;
+                      rl = t->rlink, lr = t->llink;
+                      t->llink = l, l->rlink = lr, t->rlink = r, r->llink = rl;
+                      l->balance = t->balance != 1 ? 0 : -1;
+                      r->balance = t->balance != (char) -1 ? 0 : 1;
+                      t->balance = 0;
+                      break;
+                    default:
+                      abort ();
+                    }
+                  break;
+                case 2:
+                  switch (dirs[depth + 1])
+                    {
+                    case R:
+                      l = links[depth], t = l->rlink, lr = t->llink;
+                      t->llink = l, l->rlink = lr;
+                      t->balance = l->balance = 0;
+                      break;
+                    case L:
+                      l = links[depth], r = l->rlink, t = r->llink;
+                      lr = t->llink, rl = t->rlink;
+                      t->llink = l, l->rlink = lr, t->rlink = r, r->llink = rl;
+                      l->balance = t->balance != 1 ? 0 : -1;
+                      r->balance = t->balance != (char) -1 ? 0 : 1;
+                      t->balance = 0;
+                      break;
+                    default:
+                      abort ();
+                    }
+                  break;
+                default:
+                  abort ();
+                }
 
-	      if (dirs[depth - 1] == L)
-		links[depth - 1]->llink = t;
-	      else
-		links[depth - 1]->rlink = t;
-	    }
-	}
+              if (dirs[depth - 1] == L)
+                links[depth - 1]->llink = t;
+              else
+                links[depth - 1]->rlink = t;
+            }
+        }
 
       trie = link->trie;
     }
@@ -303,7 +303,7 @@ enqueue (struct tree *tree, struct trie **last)
    well as a last resort failure node. */
 static void
 treefails (struct tree const *tree, struct trie const *fail,
-	   struct trie *recourse)
+           struct trie *recourse)
 {
   struct tree *link;
 
@@ -314,20 +314,20 @@ treefails (struct tree const *tree, struct trie const *fail,
   treefails(tree->rlink, fail, recourse);
 
   /* Find, in the chain of fails going back to the root, the first
-     node that has a descendent on the current label. */
+     node that has a descendant on the current label. */
   while (fail)
     {
       link = fail->links;
       while (link && tree->label != link->label)
-	if (tree->label < link->label)
-	  link = link->llink;
-	else
-	  link = link->rlink;
+        if (tree->label < link->label)
+          link = link->llink;
+        else
+          link = link->rlink;
       if (link)
-	{
-	  tree->trie->fail = link->trie;
-	  return;
-	}
+        {
+          tree->trie->fail = link->trie;
+          return;
+        }
       fail = fail->fail;
     }
 
@@ -338,8 +338,8 @@ treefails (struct tree const *tree, struct trie const *fail,
    the preexisting delta value is larger than the current depth. */
 static void
 treedelta (struct tree const *tree,
-	   unsigned int depth,
-	   unsigned char delta[])
+           unsigned int depth,
+           unsigned char delta[])
 {
   if (!tree)
     return;
@@ -350,7 +350,7 @@ treedelta (struct tree const *tree,
 }
 
 /* Return true if A has every label in B. */
-static int
+static int _GL_ATTRIBUTE_PURE
 hasevery (struct tree const *a, struct tree const *b)
 {
   if (!b)
@@ -406,21 +406,21 @@ kwsprep (kwset_t kws)
       /* Looking for just one string.  Extract it from the trie. */
       kwset->target = obstack_alloc(&kwset->obstack, kwset->mind);
       if (!kwset->target)
-	return _("memory exhausted");
+        return _("memory exhausted");
       for (i = kwset->mind - 1, curr = kwset->trie; i >= 0; --i)
-	{
-	  kwset->target[i] = curr->links->label;
-	  curr = curr->links->trie;
-	}
+        {
+          kwset->target[i] = curr->links->label;
+          curr = curr->links->trie;
+        }
       /* Build the Boyer Moore delta.  Boy that's easy compared to CW. */
       for (i = 0; i < kwset->mind; ++i)
-	delta[U(kwset->target[i])] = kwset->mind - (i + 1);
+        delta[U(kwset->target[i])] = kwset->mind - (i + 1);
       /* Find the minimal delta2 shift that we might make after
-	 a backwards match has failed. */
+         a backwards match has failed. */
       c = kwset->target[kwset->mind - 1];
       for (i = kwset->mind - 2; i >= 0; --i)
-	if (kwset->target[i] == c)
-	  break;
+        if (kwset->target[i] == c)
+          break;
       kwset->mind2 = kwset->mind - (i + 1);
     }
   else
@@ -429,61 +429,61 @@ kwsprep (kwset_t kws)
       struct trie *last, *next[NCHAR];
 
       /* Traverse the nodes of the trie in level order, simultaneously
-	 computing the delta table, failure function, and shift function. */
+         computing the delta table, failure function, and shift function. */
       for (curr = last = kwset->trie; curr; curr = curr->next)
-	{
-	  /* Enqueue the immediate descendents in the level order queue. */
-	  enqueue(curr->links, &last);
+        {
+          /* Enqueue the immediate descendants in the level order queue. */
+          enqueue(curr->links, &last);
 
-	  curr->shift = kwset->mind;
-	  curr->maxshift = kwset->mind;
+          curr->shift = kwset->mind;
+          curr->maxshift = kwset->mind;
 
-	  /* Update the delta table for the descendents of this node. */
-	  treedelta(curr->links, curr->depth, delta);
+          /* Update the delta table for the descendants of this node. */
+          treedelta(curr->links, curr->depth, delta);
 
-	  /* Compute the failure function for the decendents of this node. */
-	  treefails(curr->links, curr->fail, kwset->trie);
+          /* Compute the failure function for the descendants of this node.  */
+          treefails(curr->links, curr->fail, kwset->trie);
 
-	  /* Update the shifts at each node in the current node's chain
-	     of fails back to the root. */
-	  for (fail = curr->fail; fail; fail = fail->fail)
-	    {
-	      /* If the current node has some outgoing edge that the fail
-		 doesn't, then the shift at the fail should be no larger
-		 than the difference of their depths. */
-	      if (!hasevery(fail->links, curr->links))
-		if (curr->depth - fail->depth < fail->shift)
-		  fail->shift = curr->depth - fail->depth;
+          /* Update the shifts at each node in the current node's chain
+             of fails back to the root. */
+          for (fail = curr->fail; fail; fail = fail->fail)
+            {
+              /* If the current node has some outgoing edge that the fail
+                 doesn't, then the shift at the fail should be no larger
+                 than the difference of their depths. */
+              if (!hasevery(fail->links, curr->links))
+                if (curr->depth - fail->depth < fail->shift)
+                  fail->shift = curr->depth - fail->depth;
 
-	      /* If the current node is accepting then the shift at the
-		 fail and its descendents should be no larger than the
-		 difference of their depths. */
-	      if (curr->accepting && fail->maxshift > curr->depth - fail->depth)
-		fail->maxshift = curr->depth - fail->depth;
-	    }
-	}
+              /* If the current node is accepting then the shift at the
+                 fail and its descendants should be no larger than the
+                 difference of their depths. */
+              if (curr->accepting && fail->maxshift > curr->depth - fail->depth)
+                fail->maxshift = curr->depth - fail->depth;
+            }
+        }
 
       /* Traverse the trie in level order again, fixing up all nodes whose
-	 shift exceeds their inherited maxshift. */
+         shift exceeds their inherited maxshift. */
       for (curr = kwset->trie->next; curr; curr = curr->next)
-	{
-	  if (curr->maxshift > curr->parent->maxshift)
-	    curr->maxshift = curr->parent->maxshift;
-	  if (curr->shift > curr->maxshift)
-	    curr->shift = curr->maxshift;
-	}
+        {
+          if (curr->maxshift > curr->parent->maxshift)
+            curr->maxshift = curr->parent->maxshift;
+          if (curr->shift > curr->maxshift)
+            curr->shift = curr->maxshift;
+        }
 
       /* Create a vector, indexed by character code, of the outgoing links
-	 from the root node. */
+         from the root node. */
       for (i = 0; i < NCHAR; ++i)
-	next[i] = NULL;
+        next[i] = NULL;
       treenext(kwset->trie->links, next);
 
       if ((trans = kwset->trans) != NULL)
-	for (i = 0; i < NCHAR; ++i)
-	  kwset->next[i] = next[U(trans[i])];
+        for (i = 0; i < NCHAR; ++i)
+          kwset->next[i] = next[U(trans[i])];
       else
-	memcpy(kwset->next, next, NCHAR * sizeof(struct trie *));
+        memcpy(kwset->next, next, NCHAR * sizeof(struct trie *));
     }
 
   /* Fix things up for any translation table. */
@@ -497,7 +497,7 @@ kwsprep (kwset_t kws)
 }
 
 /* Fast boyer-moore search. */
-static size_t
+static size_t _GL_ATTRIBUTE_PURE
 bmexec (kwset_t kws, char const *text, size_t size)
 {
   struct kwset const *kwset;
@@ -529,35 +529,35 @@ bmexec (kwset_t kws, char const *text, size_t size)
     /* 11 is not a bug, the initial offset happens only once. */
     for (ep = text + size - 11 * len;;)
       {
-	while (tp <= ep)
-	  {
-	    d = d1[U(tp[-1])], tp += d;
-	    d = d1[U(tp[-1])], tp += d;
-	    if (d == 0)
-	      goto found;
-	    d = d1[U(tp[-1])], tp += d;
-	    d = d1[U(tp[-1])], tp += d;
-	    d = d1[U(tp[-1])], tp += d;
-	    if (d == 0)
-	      goto found;
-	    d = d1[U(tp[-1])], tp += d;
-	    d = d1[U(tp[-1])], tp += d;
-	    d = d1[U(tp[-1])], tp += d;
-	    if (d == 0)
-	      goto found;
-	    d = d1[U(tp[-1])], tp += d;
-	    d = d1[U(tp[-1])], tp += d;
-	  }
-	break;
+        while (tp <= ep)
+          {
+            d = d1[U(tp[-1])], tp += d;
+            d = d1[U(tp[-1])], tp += d;
+            if (d == 0)
+              goto found;
+            d = d1[U(tp[-1])], tp += d;
+            d = d1[U(tp[-1])], tp += d;
+            d = d1[U(tp[-1])], tp += d;
+            if (d == 0)
+              goto found;
+            d = d1[U(tp[-1])], tp += d;
+            d = d1[U(tp[-1])], tp += d;
+            d = d1[U(tp[-1])], tp += d;
+            if (d == 0)
+              goto found;
+            d = d1[U(tp[-1])], tp += d;
+            d = d1[U(tp[-1])], tp += d;
+          }
+        break;
       found:
-	if (U(tp[-2]) == gc)
-	  {
-	    for (i = 3; i <= len && U(tp[-i]) == U(sp[-i]); ++i)
-	      ;
-	    if (i > len)
-	      return tp - len - text;
-	  }
-	tp += md2;
+        if (U(tp[-2]) == gc)
+          {
+            for (i = 3; i <= len && U(tp[-i]) == U(sp[-i]); ++i)
+              ;
+            if (i > len)
+              return tp - len - text;
+          }
+        tp += md2;
       }
 
   /* Now we have only a few characters left to search.  We
@@ -568,14 +568,14 @@ bmexec (kwset_t kws, char const *text, size_t size)
     {
       d = d1[U((tp += d)[-1])];
       if (d != 0)
-	continue;
+        continue;
       if (U(tp[-2]) == gc)
-	{
-	  for (i = 3; i <= len && U(tp[-i]) == U(sp[-i]); ++i)
-	    ;
-	  if (i > len)
-	    return tp - len - text;
-	}
+        {
+          for (i = 3; i <= len && U(tp[-i]) == U(sp[-i]); ++i)
+            ;
+          if (i > len)
+            return tp - len - text;
+        }
       d = md2;
     }
 
@@ -583,7 +583,7 @@ bmexec (kwset_t kws, char const *text, size_t size)
 }
 
 /* Hairy multiple string search. */
-static size_t
+static size_t _GL_ARG_NONNULL ((4))
 cwexec (kwset_t kws, char const *text, size_t len, struct kwsmatch *kwsmatch)
 {
   struct kwset const *kwset;
@@ -627,52 +627,52 @@ cwexec (kwset_t kws, char const *text, size_t len, struct kwsmatch *kwsmatch)
   while (lim - end >= d)
     {
       if (qlim && end <= qlim)
-	{
-	  end += d - 1;
-	  while ((d = delta[c = *end]) && end < qlim)
-	    {
-	      end += d;
-	      end += delta[U(*end)];
-	      end += delta[U(*end)];
-	    }
-	  ++end;
-	}
+        {
+          end += d - 1;
+          while ((d = delta[c = *end]) && end < qlim)
+            {
+              end += d;
+              end += delta[U(*end)];
+              end += delta[U(*end)];
+            }
+          ++end;
+        }
       else
-	d = delta[c = (end += d)[-1]];
+        d = delta[c = (end += d)[-1]];
       if (d)
-	continue;
+        continue;
       beg = end - 1;
       trie = next[c];
       if (trie->accepting)
-	{
-	  mch = beg;
-	  accept = trie;
-	}
+        {
+          mch = beg;
+          accept = trie;
+        }
       d = trie->shift;
       while (beg > text)
-	{
-	  c = trans ? trans[U(*--beg)] : *--beg;
-	  tree = trie->links;
-	  while (tree && c != tree->label)
-	    if (c < tree->label)
-	      tree = tree->llink;
-	    else
-	      tree = tree->rlink;
-	  if (tree)
-	    {
-	      trie = tree->trie;
-	      if (trie->accepting)
-		{
-		  mch = beg;
-		  accept = trie;
-		}
-	    }
-	  else
-	    break;
-	  d = trie->shift;
-	}
+        {
+          c = trans ? trans[U(*--beg)] : *--beg;
+          tree = trie->links;
+          while (tree && c != tree->label)
+            if (c < tree->label)
+              tree = tree->llink;
+            else
+              tree = tree->rlink;
+          if (tree)
+            {
+              trie = tree->trie;
+              if (trie->accepting)
+                {
+                  mch = beg;
+                  accept = trie;
+                }
+            }
+          else
+            break;
+          d = trie->shift;
+        }
       if (mch)
-	goto match;
+        goto match;
     }
   return -1;
 
@@ -687,80 +687,75 @@ cwexec (kwset_t kws, char const *text, size_t len, struct kwsmatch *kwsmatch)
   while (lim - end >= d)
     {
       if ((d = delta[c = (end += d)[-1]]) != 0)
-	continue;
+        continue;
       beg = end - 1;
       if (!(trie = next[c]))
-	{
-	  d = 1;
-	  continue;
-	}
+        {
+          d = 1;
+          continue;
+        }
       if (trie->accepting && beg <= mch)
-	{
-	  lmch = beg;
-	  accept = trie;
-	}
+        {
+          lmch = beg;
+          accept = trie;
+        }
       d = trie->shift;
       while (beg > text)
-	{
-	  c = trans ? trans[U(*--beg)] : *--beg;
-	  tree = trie->links;
-	  while (tree && c != tree->label)
-	    if (c < tree->label)
-	      tree = tree->llink;
-	    else
-	      tree = tree->rlink;
-	  if (tree)
-	    {
-	      trie = tree->trie;
-	      if (trie->accepting && beg <= mch)
-		{
-		  lmch = beg;
-		  accept = trie;
-		}
-	    }
-	  else
-	    break;
-	  d = trie->shift;
-	}
+        {
+          c = trans ? trans[U(*--beg)] : *--beg;
+          tree = trie->links;
+          while (tree && c != tree->label)
+            if (c < tree->label)
+              tree = tree->llink;
+            else
+              tree = tree->rlink;
+          if (tree)
+            {
+              trie = tree->trie;
+              if (trie->accepting && beg <= mch)
+                {
+                  lmch = beg;
+                  accept = trie;
+                }
+            }
+          else
+            break;
+          d = trie->shift;
+        }
       if (lmch)
-	{
-	  mch = lmch;
-	  goto match;
-	}
+        {
+          mch = lmch;
+          goto match;
+        }
       if (!d)
-	d = 1;
+        d = 1;
     }
 
-  if (kwsmatch)
-    {
-      kwsmatch->index = accept->accepting / 2;
-      kwsmatch->offset[0] = mch - text;
-      kwsmatch->size[0] = accept->depth;
-    }
+  kwsmatch->index = accept->accepting / 2;
+  kwsmatch->offset[0] = mch - text;
+  kwsmatch->size[0] = accept->depth;
+
   return mch - text;
 }
 
-/* Search through the given text for a match of any member of the
-   given keyword set.  Return a pointer to the first character of
-   the matching substring, or NULL if no match is found.  If FOUNDLEN
-   is non-NULL store in the referenced location the length of the
-   matching substring.  Similarly, if FOUNDIDX is non-NULL, store
-   in the referenced location the index number of the particular
-   keyword matched. */
+/* Search TEXT for a match of any member of the keyword set, KWS.
+   Return the offset (into TEXT) of the first byte of the matching substring,
+   or (size_t) -1 if no match is found.  Upon a match, store details in
+   *KWSMATCH: index of matched keyword, start offset (same as the return
+   value), and length.  */
 size_t
-kwsexec (kwset_t kws, char const *text, size_t size,
-	 struct kwsmatch *kwsmatch)
+kwsexec (kwset_t kws, char const *text, size_t size, struct kwsmatch *kwsmatch)
 {
   struct kwset const *kwset = (struct kwset *) kws;
   if (kwset->words == 1 && kwset->trans == NULL)
     {
       size_t ret = bmexec (kws, text, size);
-      if (kwsmatch != NULL && ret != (size_t) -1)
-	{
-	  kwsmatch->index = 0;
-	  kwsmatch->offset[0] = ret;
-	  kwsmatch->size[0] = kwset->mind;
-	}
+      if (ret != (size_t) -1)
+        {
+          kwsmatch->index = 0;
+          kwsmatch->offset[0] = ret;
+          kwsmatch->size[0] = kwset->mind;
+        }
       return ret;
     }
   else
